@@ -7,7 +7,7 @@ from typing import List, Dict, Any, Optional
 log=logging.getLogger(__name__)
 log.setLevel(logging.WARNING)
 formatter = logging.Formatter(
-    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    fmt="%(asctime)s | %(levelname)s | thread-%(threadName)s | %(filename)s:%(lineno)d | %(message)s",
     datefmt="%Y-%m-%d %H:%M:%S"
 )
 console_handler = logging.StreamHandler()
